Contributors
============

jobflow was designed and developed by **Alex Ganose** |utf| |0000-0002-4486-3321|.
The project was led by **Anubhav Jain** |computron| |0000-0001-5893-9967| at Lawrence
Berkeley National Laboratory.

.. |utf| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/utf
   :width: 16
   :height: 16
   :alt: GitHub profile for utf
.. |0000-0002-4486-3321| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0002-4486-3321
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-4486-3321

.. |computron| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/computron
   :width: 16
   :height: 16
   :alt: GitHub profile for computron
.. |0000-0001-5893-9967| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0001-5893-9967
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0001-5893-9967

Additional contributions provided by:

| **David Waroquiers** |davidwaroquiers| |0000-0001-8943-9762|
| Université Catholique de Louvain

.. |davidwaroquiers| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/davidwaroquiers
   :width: 16
   :height: 16
   :alt: GitHub profile for davidwaroquiers
.. |0000-0001-8943-9762| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0001-8943-9762
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0001-8943-9762

| **Andrew Rosen** |arosen| |0000-0002-0141-7006|
| Miller Research Fellow
| University of California, Berkeley

.. |arosen| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/arosen93
   :width: 16
   :height: 16
   :alt: GitHub profile for arosen93
.. |0000-0002-0141-7006| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0002-0141-7006
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-0141-7006

| **Jimmy-Xuan Shen** |jmmshn| |0000-0002-2743-7531|
| Postdoctoral researcher
| Lawrence Livermore National Laboratory

.. |jmmshn| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/jmmshn
   :width: 16
   :height: 16
   :alt: GitHub profile for jmmshn
.. |0000-0002-2743-7531| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0002-0141-7006
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-2743-7531

| **Guido Petretto** |gpetretto|
| Université Catholique de Louvain

.. |gpetretto| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/gpetretto
   :width: 16
   :height: 16
   :alt: GitHub profile for gpetretto

| **Janosh Riebesell** |janosh|
| Cambridge University

.. |janosh| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/janosh
   :width: 16
   :height: 16
   :alt: GitHub profile for janosh

| **Mingjian Wen** |mjwen| |0000-0003-0013-575X|
| Postdoctoral researcher
| Lawrence Berkeley National Laboratory

.. |mjwen| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/mjwen
   :width: 16
   :height: 16
   :alt: GitHub profile for mjwen
.. |0000-0003-0013-575X| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0003-0013-575X
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0003-0013-575X
